# CordStore
Utilize discord to store files in textchannels using bots or webhooks

---

### Installation
```
# Linux/macOS
python3 -m pip install -U cordstore

# Windows
py -3 -m pip install -U cordstore
```
